@@ -15,7 +15,7 @@ from netket.utils.types import PyTree
 from netket.utils.dispatch import dispatch, TrueT, FalseT
 
 from netket.operator import (
-    AbstractOperator,
+    DiscreteOperator,
     AbstractSuperOperator,
     local_cost_function,
     local_value_cost,
@@ -40,7 +40,7 @@ def _check_hilbert(A, B):
 @dispatch
 def expect_and_grad(
     vstate: MCState,
-    Ô: Squared[AbstractOperator],
+    Ô: Squared[DiscreteOperator],
     use_covariance: TrueT,
     mutable: Any,
 ) -> Tuple[Stats, PyTree]:
@@ -102,12 +102,12 @@ def expect_and_grad(  # noqa: F811
 
 # mixed state, hermitian operator
 @dispatch.multi(
-    (MCState, AbstractOperator, TrueT, Any),
+    (MCState, DiscreteOperator, TrueT, Any),
     (MCMixedState, AbstractSuperOperator, TrueT, Any),
 )
 def expect_and_grad(  # noqa: F811
     vstate: MCState,
-    Ô: AbstractOperator,
+    Ô: DiscreteOperator,
     use_covariance: TrueT,
     mutable: Any,
 ) -> Tuple[Stats, PyTree]:
@@ -136,7 +136,7 @@ def expect_and_grad(  # noqa: F811
 @dispatch
 def expect_and_grad(  # noqa: F811
     vstate: MCState,
-    Ô: AbstractOperator,
+    Ô: DiscreteOperator,
     use_covariance: FalseT,
     mutable: Any,
 ) -> Tuple[Stats, PyTree]:
@@ -196,20 +196,13 @@ def grad_expect_hermitian(
     # Then compute the vjp.
     # Code is a bit more complex than a standard one because we support
     # mutable state (if it's there)
-    if mutable is False:
-        _, vjp_fun = nkjax.vjp(
-            lambda w: model_apply_fun({"params": w, **model_state}, σ),
-            parameters,
-            conjugate=True,
-        )
-        new_model_state = None
-    else:
-        _, vjp_fun, new_model_state = nkjax.vjp(
-            lambda w: model_apply_fun({"params": w, **model_state}, σ, mutable=mutable),
-            parameters,
-            conjugate=True,
-            has_aux=True,
-        )
+    is_mutable = mutable is not False
+    _, vjp_fun, *new_model_state = nkjax.vjp(
+        lambda w: model_apply_fun({"params": w, **model_state}, σ, mutable=mutable),
+        parameters,
+        conjugate=True,
+        has_aux=is_mutable,
+    )
     Ō_grad = vjp_fun(jnp.conjugate(O_loc) / n_samples)[0]
 
     Ō_grad = jax.tree_multimap(
@@ -220,6 +213,8 @@ def grad_expect_hermitian(
         parameters,
     )
 
+    new_model_state = new_model_state[0] if is_mutable else None
+
     return Ō, tree_map(lambda x: mpi.mpi_sum_jax(x)[0], Ō_grad), new_model_state
 
 
